@@ -20,7 +20,7 @@
 ############ GENERATED CODE ############
 ########################################
 
-'''Generated at: 2013-12-24 11:16:42.676341'''
+'''Generated at: 2014-01-19 16:05:55.954861'''
 
 import types
 import urlparse
@@ -61,7 +61,7 @@ class API(object):
                  renew_session=False, insecure=False, validate_cert_chain=True, filter=False, debug=False):  # @ReservedAssignment
 
         '''
-        @param url: server url (format "http/s://server[:port]/api")
+        @param url: server url (format "http/s://server[:port]/ovirt-engine/api")
         @param username: user (format user@domain)
         @param password: password
         [@param key_file: client PEM key_file for ssl enabled connection]
@@ -96,6 +96,16 @@ class API(object):
         if context.manager.has_key(self.__id):
             self.disconnect()
 
+        # Remove trailing slashes from the URL:
+        url = url.rstrip('/')
+
+        # For backwards compatibility we need to support URLs that don't
+        # contain a path, and in that case the path should be the old /api:
+        prefix = urlparse.urlparse(url).path
+        if prefix == '':
+            prefix = '/api'
+            url = url + prefix
+
         # Create the connection pool:
         pool = ConnectionsPool(
             url=url,
@@ -116,7 +126,8 @@ class API(object):
         # Create the proxy:
         proxy = Proxy(
             pool,
-            persistent_auth
+            persistent_auth,
+            prefix
         )
 
         # Store filter to the context:
@@ -131,7 +142,7 @@ class API(object):
         # Get entry point
         entry_point = proxy.request(
             method='GET',
-            url=urlparse.urlparse(url).path
+            url=''
         )
 
         # If server returns no response for the root resource, this is sign
@@ -207,7 +218,7 @@ class API(object):
                 try:
                     proxy.request(
                         method='GET',
-                        url='/api',
+                        url='',
                         last=True
                     )
                 except Exception:
@@ -226,7 +237,7 @@ class API(object):
             try :
                 proxy.request(
                     method='GET',
-                    url='/api'
+                    url=''
                 )
             except Exception, e:
                 if throw_exception: raise e
@@ -268,6 +279,7 @@ class API(object):
     def __exit__(self, type, value, tb):  # @ReservedAssignment
         self.disconnect()
 
+
     def get_comment(self):
         entry_point = context.manager[self.id].get('entry_point')
         if entry_point:
@@ -286,7 +298,7 @@ class API(object):
         if proxy:
             return proxy.request(
                 method='GET',
-                url='/api'
+                url=''
             ).summary
 
         raise DisconnectedError
@@ -296,7 +308,7 @@ class API(object):
         if proxy:
             return proxy.request(
                 method='GET',
-                url='/api'
+                url=''
             ).time
 
         raise DisconnectedError
